@@ -8,7 +8,8 @@ function(para) {
               LCV  = NULL,
               L3   = NULL,
               L4   = NULL,
-              L5   = NULL
+              L5   = NULL,
+              source = "lmomexp--ordinary"
              )
     if(! are.parexp.valid(para)) return()
     A <- para$para[2]
