@@ -126,6 +126,8 @@ function(lmom,result='best',verbose=FALSE) {
     validlmom <- function(sol,attempt) {
       LM3 <- sol$par[1]
       LM4 <- sol$par[2]
+      # L-moment based GLD only valid for > -1 parameters--Hosking email
+      if(LM3 <= -1 || LM4 <= -1) return(FALSE)
       T3 <- esttau3(LM3,LM4)
       T4 <- esttau4(LM3,LM4)
       T5 <- esttau5(LM3,LM4)
@@ -241,8 +243,8 @@ function(lmom,result='best',verbose=FALSE) {
    para[2]  <- EACH$a[1]
    para[3]  <- EACH$k[1]
    para[4]  <- EACH$h[1]
-   tau5diff <- EACH$tau5diff[1]
-   error    <- EACH$mse[1]
+   tau5diff <- EACH$absDelTau5[1]
+   error    <- EACH$error[1]
    
    if(result == 'best') {
      return(list(type       = 'gld',
